Command line interface
======================

Animanager's primary interactive interface is its command line.  It works
similarly to shells such as bash and supports command editing through the
readline library.  Command help is available via the ``help`` or ``?`` command.
